@@ -807,8 +807,10 @@ class PaymentProfile(ModelSQL, ModelView):
         ('10', '10-October'),
         ('11', '11-November'),
         ('12', '12-December'),
-    ], 'Expiry Month', required=True)
-    expiry_year = fields.Char('Expiry Year', required=True, size=4)
+    ], 'Expiry Month', required=True, readonly=True)
+    expiry_year = fields.Char(
+        'Expiry Year', required=True, size=4, readonly=True
+    )
     active = fields.Boolean('Active', select=True)
 
     @staticmethod
@@ -921,6 +923,11 @@ class AddPaymentProfile(Wizard):
             **kwargs
         )
         profile.save()
+
+        # Wizard session data is stored in database
+        # Make sure credit card info does not hit the database
+        self.card_info.number = None
+        self.card_info.csc = None
         return profile
 
     def transition_add(self):
@@ -992,6 +999,7 @@ class TransactionUseCard(Wizard):
             self.card_info
         )
 
+        self.clear_cc_info()
         return 'end'
 
     def transition_authorize(self):
@@ -1009,4 +1017,13 @@ class TransactionUseCard(Wizard):
             self.card_info
         )
 
+        self.clear_cc_info()
         return 'end'
+
+    def clear_cc_info(self):
+        """
+        Tryton stores Wizard session data while it's execution
+        We need to make sure credit card info does not hit the database
+        """
+        self.card_info.number = None
+        self.card_info.csc = None
